# -*- coding: utf-8 -*-
'''
A simple command line utility for translating text
using Google Translate.
'''

from .translator import *
from .languages import *
from .__version__ import __version__, __build__

__title__ = 'translate'
__author__ = 'Sang Han'
__license__ = 'Apache Software License Version 2.0'
__copyright__ = 'Sang Han 2014'
